
      subroutine float2int_0D(float_number,offset,scale,int_number)


      implicit none

      include 'missing_values.inc'

c     Input:
      real float_number,offset,scale

c     Output:
      integer int_number

c     Local:
      real limit

      limit = 0.99*miss_val_r(1)

      if (float_number .lt. limit) then
         int_number = miss_val_i4(1)
      else
         int_number = nint( (float_number - offset)/scale )
      end if

      return
      end



      subroutine float2int_1D(nx,float_array,offset,scale,int_array)


      implicit none

      include 'missing_values.inc'

c     Input:
      integer nx
      real float_array(nx),offset,scale

c     Output:
      integer int_array(nx)

c     Local:
      integer x
      real limit

      limit = 0.99*miss_val_r(1)

      do x = 1,nx
         if (float_array(x) .lt. limit) then
            int_array(x) = miss_val_i4(1)
         else
            int_array(x) = nint( (float_array(x) - offset)/scale )
         end if
      end do

      return
      end



      subroutine float2int_2D(nx,ny,float_array,offset,scale,
     >                          int_array)


      implicit none

      include 'missing_values.inc'

c     Input:
      integer nx,ny
      real float_array(nx,ny),offset,scale

c     Output:
      integer int_array(nx,ny)

c     Local:
      integer x,y
      real limit

      limit = 0.99*miss_val_r(1)

      do y = 1,ny
         do x = 1,nx
            if (float_array(x,y) .lt. limit) then
               int_array(x,y) = miss_val_i4(1)
            else
               int_array(x,y) = nint( (float_array(x,y) - offset)/
     >                                scale )
            end if
         end do
      end do

      return
      end



      subroutine float2int_3D(nx,ny,nz,float_array,offset,scale,
     >                        int_array)


      implicit none

      include 'missing_values.inc'

c     Input:
      integer nx,ny,nz
      real float_array(nx,ny,nz),offset,scale

c     Output:
      integer int_array(nx,ny,nz)

c     Local:
      integer x,y,z
      real limit

      limit = 0.99*miss_val_r(1)

      do z = 1,nz
         do y = 1,ny
            do x = 1,nx
               if (float_array(x,y,z) .lt. limit) then
                  int_array(x,y,z) = miss_val_i4(1)
               else
                  int_array(x,y,z) = nint( (float_array(x,y,z) -
     >                                      offset)/scale )
               end if
            end do
         end do
      end do

      return
      end



      subroutine float2int_4D(nx,ny,nz,nt,float_array,offset,scale,
     >                        int_array)


      implicit none

      include 'missing_values.inc'

c     Input:
      integer nx,ny,nz,nt
      real float_array(nx,ny,nz,nt),offset,scale

c     Output:
      integer int_array(nx,ny,nz,nt)

c     Local:
      integer x,y,z,t
      real limit

      limit = 0.99*miss_val_r(1)

      do t = 1,nt
         do z = 1,nz
            do y = 1,ny
               do x = 1,nx
                  if (float_array(x,y,z,t) .lt. limit) then
                     int_array(x,y,z,t) = miss_val_i4(1)
                  else
                     int_array(x,y,z,t) = nint( (float_array(x,y,z,t) -
     >                                           offset)/scale )
               end if
               end do
            end do
         end do
      end do

      return
      end



      subroutine int2float_0D(int_number,offset,scale,float_number)


      implicit none

      include 'missing_values.inc'

c     Input:
      integer int_number
      real offset,scale

c     Output:
      real float_number

      if (int_number .ne. miss_val_i4(1)) then
         float_number = scale*float(int_number) + offset
      else
         float_number = miss_val_r(1)
      end if

      return
      end



      subroutine int2float_1D(nx,int_array,offset,scale,float_array)


      implicit none

      include 'missing_values.inc'

c     Input:
      integer nx
      integer int_array(nx)
      real offset,scale

c     Output:
      real float_array(nx)

c     Local:
      integer x

      do x = 1,nx
         if (int_array(x) .ne. miss_val_i4(1)) then
            float_array(x) = scale*float(int_array(x)) + offset
         else
            float_array(x) = miss_val_r(1)
         end if
      end do

      return
      end



      subroutine int2float_2D(nx,ny,int_array,offset,scale,float_array)


      implicit none

      include 'missing_values.inc'

c     Input:
      integer nx,ny
      integer int_array(nx,ny)
      real offset,scale

c     Output:
      real float_array(nx,ny)

c     Local:
      integer x,y

      do y = 1,ny
         do x = 1,nx
            if (int_array(x,y) .ne. miss_val_i4(1)) then
               float_array(x,y) = scale*float(int_array(x,y)) + offset
            else
               float_array(x,y) = miss_val_r(1)
            end if
         end do
      end do

      return
      end



      subroutine int2float_3D(nx,ny,nz,int_array,offset,scale,
     >                        float_array)


      implicit none

      include 'missing_values.inc'

c     Input:
      integer nx,ny,nz
      integer int_array(nx,ny,nz)
      real offset,scale

c     Output:
      real float_array(nx,ny,nz)

c     Local:
      integer x,y,z

      do z = 1,nz
         do y = 1,ny
            do x = 1,nx
               if (int_array(x,y,z) .ne. miss_val_i4(1)) then
                  float_array(x,y,z) = scale*float(int_array(x,y,z)) +
     >                                 offset
               else
                  float_array(x,y,z) = miss_val_r(1)
               end if
            end do
         end do
      end do

      return
      end



      subroutine int2float_4D(nx,ny,nz,nt,int_array,offset,scale,
     >                        float_array)


      implicit none

      include 'missing_values.inc'

c     Input:
      integer nx,ny,nz,nt
      integer int_array(nx,ny,nz,nt)
      real offset,scale

c     Output:
      real float_array(nx,ny,nz,nt)

c     Local:
      integer x,y,z,t

      do t = 1,nt
         do z = 1,nz
            do y = 1,ny
               do x = 1,nx
                  if (int_array(x,y,z,t) .ne. miss_val_i4(1)) then
                     float_array(x,y,z,t) =
     >                    scale*float(int_array(x,y,z,t)) + offset
                  else
                     float_array(x,y,z,t) = miss_val_r(1)
                  end if
               end do
            end do
         end do
      end do

      return
      end

