#!/bin/sh

echo ""
echo "        nc_climatology.sh  Version 1.1"
echo "        Written by Arne Melsom"
echo "           a.melsom@dnmi.no"
echo "            (+47) 2296 3316"
echo "             March 2, 2001"
echo ""


# Check syntax:
###############

if [ "$2" = "" ]
then
    echo ">>>   SYNTAX ERROR   <<<"
    echo ""
    echo ">>> nc_climatology.sh adds monthly climatology to a netCDF file"
    echo ">>>                   using NOClim convensions."
    echo ">>>                   The climatology consists of fields for"
    echo ">>>                    no. of occurences      [integer]"
    echo ">>>                    mean values            [real]"
    echo ">>>                    standard deviations    [real]"
    echo ">>>                    overall minimum values [real]"
    echo ">>>                    overall maximum values [real]"
    echo ">>>                   for each month and vertical level,"
    echo ">>>                   for each time dependent variable."
    echo ""
    echo ">>> Format:"
    echo ">>>  nc_climatology.sh /filelist/ /variable/ /firstyear/ /lastyear/" 
    echo ">>> where"
    echo ">>>   /file_list/    is the name of a file that contains"
    echo ">>>                   * no. of file names on line 1"
    echo ">>>                      (if a negative number is used, at least"
    echo ">>>                       one value per month, for each year,"
    echo ">>>                       must be present, otherwise the grid"
    echo ">>>                       will be masked)"
    echo ">>>                   * list of input file names on following lines"
    echo ">>>                   * output file name on the final line"
    echo ">>>                     (if there is only one input file,"
    echo ">>>                      this file may also be the output file)"
    echo ">>>   /variable/     is the name of the variable for which"
    echo ">>>                   monthly climatology will be added"
    echo ">>>   /firstyear/    is the first year to consider (optional)"
    echo ">>>   /lastyear/     is the last year to consider"
    echo ">>>                   (optional, if present, requires /firstyear/)"
    echo ""
    echo ">>> Script terminates."
    echo ""
    exit
fi


# Read command line argumnts:
#############################

filelist=$1
vrbl_name=$2
if [ "$3" = "" ]
then
    firstyear=-999
    lastyear=9999
else
    firstyear=$3
    if [ "$4" = "" ]
    then
        lastyear=9999
    else
        lastyear=$4
    fi
fi


# Require non-existing flag file:
#################################

test -r ok_flag && echo ">>> Flag file exists!"
test -r ok_flag && echo ">>> Script terminates prematurely."
test -r ok_flag && echo ""
test -r ok_flag && exit


# Compile "nc_dims" if necessary:
#################################

test -r nc_dims || make -f nc_dims.make
test -r nc_dims || echo ">>> Compilation of 'nc_dims' failed."
test -r nc_dims || echo ">>> Script terminates."
test -r nc_dims || echo ""
test -r nc_dims || exit


# Run "nc_dims":
################

./nc_dims <$filelist
test -r ok_flag || echo ">>> Execution of 'nc_dims' failed."
test -r ok_flag || echo ">>> Script terminates."
test -r ok_flag || echo ""
test -r ok_flag || exit
/bin/rm ok_flag


# (Re-)Compile "nc_climatology":
################################

test -r nc_climatology && /bin/rm nc_climatology
/bin/make -f nc_climatology.make
/bin/rm *.o
test -r nc_climatology || echo ">>> Compilation of 'nc_climatology' failed!"
test -r nc_climatology || echo ">>> Script terminates prematurely."
test -r nc_climatology || echo ""
test -r nc_climatology || exit


# Run "nc_climatology":
#######################

./nc_climatology $vrbl_name $firstyear $lastyear <$filelist
test -r ok_flag || echo ">>> Execution of 'nc_climatology' failed!"
test -r ok_flag || echo ">>> Script terminates prematurely."
test -r ok_flag || echo ""
test -r ok_flag || exit
/bin/rm ok_flag

exit
